@@ -16,10 +16,10 @@ from __future__ import absolute_import
 import logging
 from typing import Union, List, Dict, Optional
 
-from sagemaker import Model, PipelineModel
+from sagemaker import Model, PipelineModel, Session
 from sagemaker.workflow._utils import _RegisterModelStep, _RepackModelStep
 from sagemaker.workflow.pipeline_context import PipelineSession, _ModelStepArguments
-from sagemaker.workflow.retry import RetryPolicy
+from sagemaker.workflow.retry import RetryPolicy, SageMakerJobStepRetryPolicy
 from sagemaker.workflow.step_collections import StepCollection
 from sagemaker.workflow.steps import Step, CreateModelStep
 
@@ -40,7 +40,7 @@ class ModelStep(StepCollection):
         self,
         name: str,
         step_args: _ModelStepArguments,
-        depends_on: Optional[Union[List[str], List[Step]]] = None,
+        depends_on: Optional[List[Union[str, Step, StepCollection]]] = None,
         retry_policies: Optional[Union[List[RetryPolicy], Dict[str, List[RetryPolicy]]]] = None,
         display_name: Optional[str] = None,
         description: Optional[str] = None,
@@ -51,22 +51,78 @@ class ModelStep(StepCollection):
             name (str): The name of the `ModelStep`. A name is required and must be
                 unique within a pipeline.
             step_args (_ModelStepArguments): The arguments for the `ModelStep` definition.
-            depends_on (List[str] or List[Step]): A list of `Step` names or `Step` instances
-                that this `ModelStep` depends on.
+            depends_on (List[Union[str, Step, StepCollection]]): A list of `Step`/`StepCollection`
+                names or `Step` instances or `StepCollection` instances that the first step,
+                in this `ModelStep` collection, depends on.
                 If a listed `Step` name does not exist, an error is returned (default: None).
             retry_policies (List[RetryPolicy] or Dict[str, List[RetryPolicy]]): The list of retry
                 policies for the `ModelStep` (default: None).
+
+                If a list of retry policies is provided, it would be applied to all steps in the
+                `ModelStep` collection. Note: in this case, `SageMakerJobStepRetryPolicy`
+                is not allowed, since create/register model step does not support it.
+                Please find the example below:
+
+                .. code:: python
+
+                    ModelStep(
+                        ...
+                        retry_policies=[
+                            StepRetryPolicy(...),
+                        ],
+                    )
+
+                If a dict is provided, it can specify different retry policies for different
+                types of steps in the `ModelStep` collection. Similarly,
+                `SageMakerJobStepRetryPolicy` is not allowed for create/register model step.
+                See examples below:
+
+                .. code:: python
+
+                    ModelStep(
+                        ...
+                        retry_policies=dict(
+                           register_model_retry_policies=[
+                               StepRetryPolicy(...),
+                           ],
+                           repack_model_retry_policies=[
+                               SageMakerJobStepRetryPolicy(...),
+                           ],
+                        )
+                    )
+
+                or
+
+                .. code:: python
+
+                    ModelStep(
+                        ...
+                        retry_policies=dict(
+                           create_model_retry_policies=[
+                               StepRetryPolicy(...),
+                           ],
+                           repack_model_retry_policies=[
+                               SageMakerJobStepRetryPolicy(...),
+                           ],
+                        )
+                    )
+
             display_name (str): The display name of the `ModelStep`.
                 The display name provides better UI readability. (default: None).
             description (str): The description of the `ModelStep` (default: None).
         """
-        # TODO: add a doc link in error message once ready
-        if not isinstance(step_args, _ModelStepArguments):
-            raise TypeError(
-                "To correctly configure a ModelStep, "
-                "the step_args must be a `_ModelStepArguments` object generated by "
-                ".create() or .register()."
-            )
+        from sagemaker.workflow.utilities import validate_step_args_input
+
+        validate_step_args_input(
+            step_args=step_args,
+            expected_caller={
+                Session.create_model.__name__,
+                Session.create_model_package_from_containers.__name__,
+            },
+            error_message="The step_args of ModelStep must be obtained from model.create() "
+            "or model.register(). For more, see: https://sagemaker.readthedocs.io/en/stable/"
+            "amazon_sagemaker_model_building_pipeline.html#model-step",
+        )
         if not (step_args.create_model_request is None) ^ (
             step_args.create_model_package_request is None
         ):
@@ -92,7 +148,22 @@ class ModelStep(StepCollection):
         self._create_model_args = self.step_args.create_model_request
         self._register_model_args = self.step_args.create_model_package_request
         self._need_runtime_repack = self.step_args.need_runtime_repack
+        self._assign_and_validate_retry_policies(retry_policies)
 
+        if self._need_runtime_repack:
+            self._append_repack_model_step()
+        if self._register_model_args:
+            self._append_register_model_step()
+        else:
+            self._append_create_model_step()
+
+    def _assign_and_validate_retry_policies(self, retry_policies):
+        """Assign and validate retry policies according to each kind of sub steps
+
+        Args:
+            retry_policies (List[RetryPolicy] or Dict[str, List[RetryPolicy]]): The list of retry
+                policies for the `ModelStep`.
+        """
         if isinstance(retry_policies, dict):
             self._create_model_retry_policies = retry_policies.get(
                 _CREATE_MODEL_RETRY_POLICIES, None
@@ -108,12 +179,23 @@ class ModelStep(StepCollection):
             self._register_model_retry_policies = retry_policies
             self._repack_model_retry_policies = retry_policies
 
-        if self._need_runtime_repack:
-            self._append_repack_model_step()
-        if self._register_model_args:
-            self._append_register_model_step()
-        else:
-            self._append_create_model_step()
+        self._validate_sagemaker_job_step_retry_policy()
+
+    def _validate_sagemaker_job_step_retry_policy(self):
+        """Validate SageMakerJobStepRetryPolicy
+
+        Validate that SageMakerJobStepRetryPolicy is not assigning to create/register model step.
+        """
+        retry_policies = set(
+            (self._create_model_retry_policies or []) + (self._register_model_retry_policies or [])
+        )
+        for policy in retry_policies:
+            if not isinstance(policy, SageMakerJobStepRetryPolicy):
+                continue
+            raise ValueError(
+                "SageMakerJobStepRetryPolicy is not allowed for a create/register"
+                " model step. Please use StepRetryPolicy instead"
+            )
 
     def _append_register_model_step(self):
         """Create and append a `_RegisterModelStep`"""
